<?php


namespace Yjtec\Rbac\Controllers;


use Yjtec\Rbac\Repositories\Contracts\MenuHostInterface;
use Yjtec\Rbac\Requests\MenuHost\SortRequest;
use Yjtec\Rbac\Requests\MenuHost\HostStoreRequest;
use Yjtec\Rbac\Requests\MenuHost\HostUpdateRequest;
use Yjtec\Rbac\Resources\MenuHost\HostListsResource;
use Yjtec\Rbac\Resources\MenuHost\HostStoreResource;
use Yjtec\Rbac\Resources\MenuHost\HostResource;

class MenuHostController extends Controller
{

    private $menuHost;
    public function __construct(MenuHostInterface $menuHost){

        $this->menuHost = $menuHost;
    }

    /**
     * @OA\Get(
     *     path="/host",
     *     description="Host列表",
     *     tags={"MenuHost"},
     *     summary="Host列表",
     *      operationId="MenuHostList",
     *     @OA\Response(
     *         response="200",
     *         description="新增成功"
     *     )
     * )
     */
    public function index(){

        $res =  $this->menuHost->lists();

        return new HostListsResource($res);
    }

    /**
     * @OA\Post(
     *     path="/host",
     *     description="新增Host",
     *     tags={"MenuHost"},
     *     summary="新增Host",
     *      operationId="MenuHostStore",
     *
     *     @OA\Parameter(
     *         description="名称",
     *         in="query",
     *         name="title",
     *         example="管理端",
     *         @OA\Schema(
     *             type="string"
     *         )
     *     ),
     *     @OA\Parameter(
     *         description="标识",
     *         in="query",
     *         name="domain",
     *         example="npc.test.jsvry.com",
     *         @OA\Schema(
     *             type="string"
     *         )
     *     ),
     *     @OA\Parameter(
     *         name="icon",
     *         in="query",
     *         description="icon",
     *         example="/menu/icon/1.icon",
     *         @OA\Schema(
     *           type="string",
     *         ),
     *         style="form"
     *     ),
     *     @OA\Parameter(
     *         name="sort",
     *         in="query",
     *         description="排序",
     *         example="1",
     *         @OA\Schema(
     *           type="integer",
     *         ),
     *         style="form"
     *     ),
     *     @OA\Response(
     *         response="200",
     *         description="新增成功"
     *     )
     * )
     */
    public function store(HostStoreRequest $request){

        $data = $request->only(['title','domain','icon','sort']);
        $res = $this->menuHost->add($data);
        if ($res) {
            
            return new HostStoreResource([]);
        }

        tne('FAIL');
    }

    /**
     * @OA\Get(
     *     path="/host/{id}",
     *     description="获取Host",
     *     tags={"MenuHost"},
     *     summary="获取Host",
     *     operationId="MenuHostInfo",
     *     @OA\Parameter(
     *         description="ID",
     *         in="path",
     *         name="id",
     *         example="1",
     *         @OA\Schema(
     *             type="integer"
     *         )
     *     ),
     *     @OA\Response(
     *         response="200",
     *         description="修改成功"
     *     )
     * )
     */
    public function info($id){

        $res = $this->menuHost->findBy($id);
        if ($res) {

            return new HostResource($res);
        }
        tne('FAIL');
    }

    /**
     * @OA\Put(
     *     path="/host",
     *     description="更新Host",
     *     tags={"MenuHost"},
     *     summary="更新Host",
     *      operationId="MenuHostUpdate",
     *
     *     @OA\Parameter(
     *         description="ID",
     *         in="query",
     *         name="id",
     *         example="1",
     *         @OA\Schema(
     *             type="integer"
     *         )
     *     ),
     *
     *     @OA\Parameter(
     *         description="名称",
     *         in="query",
     *         name="title",
     *         example="管理端",
     *         @OA\Schema(
     *             type="string"
     *         )
     *     ),
     *     @OA\Parameter(
     *         description="标识",
     *         in="query",
     *         name="domain",
     *         example="npc.test.jsvry.com",
     *         @OA\Schema(
     *             type="string"
     *         )
     *     ),
     *     @OA\Parameter(
     *         name="sort",
     *         in="query",
     *         description="排序",
     *         example="1",
     *         @OA\Schema(
     *           type="integer",
     *         ),
     *         style="form"
     *     ),
     *     @OA\Parameter(
     *         name="icon",
     *         in="query",
     *         description="icon",
     *         @OA\Schema(
     *           type="string"
     *         ),
     *         style="form"
     *     ),
     *     @OA\Response(
     *         response="200",
     *         description="修改成功"
     *     )
     * )
     */
    public function update(HostUpdateRequest $request){

        $data = $request->only(['title','domain','icon','sort']);
        $res = $this->menuHost->update(['id'=>$request->id],$data);
        if ($res) {

            return new HostStoreResource([]);
        }

        tne('FAIL');
    }

    /**
     * @OA\Delete (
     *     path="/host/{id}",
     *     description="删除host",
     *     tags={"MenuHost"},
     *     summary="删除host",
     *      operationId="MenuHostDelete",
     *
     *     @OA\Parameter(
     *         description="ID",
     *         in="path",
     *         name="id",
     *         example="1",
     *         @OA\Schema(
     *             type="integer"
     *         )
     *     ),
     *      @OA\Response(
     *         response="200",
     *         description="修改成功"
     *     )
     *  )
     */
    public function delete($id){
        
        $res = $this->menuHost->delete(['id'=>$id]);
        if ($res) {

            return new HostStoreResource([]);
        }

        tne('FAIL');
    }

    /**
     * @OA\Post(
     *     path="/host/sort",
     *     description="排序",
     *     tags={"MenuHost"},
     *     summary="排序",
     *     operationId="MenuHostSort",
     *     @OA\Parameter(
     *         name="id",
     *         in="query",
     *         description="",
     *         example="[{id:1,sort:1},{id:2,sort:2}]",
     *         @OA\Schema(
     *           type="string",
     *         ),
     *         style="form"
     *     ),
     *     @OA\Response(
     *         response="200",
     *         description="获取成功",
     *     )
     * )
     */
    public function sort(SortRequest $request){

        $sortJsonArr = json_decode($request->input('sort_json_arr'),true);
        if (is_array($sortJsonArr)) {

            $res = $this->menuHost->sort($sortJsonArr);
            if ($res) {

                tne('SUCCESS');
            }
        }

        tne('FAIL');
    }
}